#
# spec file for package lbdb
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lbdb
Summary:        Address Database for mutt
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Utilities
Version:        0.39
Release:        4.3
Url:            http://www.spinnaker.de/lbdb/
Source:         http://www.spinnaker.de/debian/lbdb_%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch:          lbdb.rc.dif
Patch2:         lbdb-hostname.diff
Suggests:       perl(Net::LDAP)
Suggests:       perl(Getopt::Long)

%description
The Little Brother's Database (lbdb) consists of a set of small tools
that collect mail addresses from several sources and offer these
addresses to the external query feature of the Mutt mail reader.

To use the fetch address feature, put the following lines in your
.procmailrc:

:0hc | lbdb-fetchaddr

To use the database in mutt, put the following line into your .muttrc:

set query_command="lbdbq %s"

%prep
%setup -n lbdb-%{version}
%patch -p0
%patch2 -p1

%build
CFLAGS="%{optflags} -fno-strict-aliasing" \
    PGP=/usr/bin/pgp PGPK=/usr/bin/pgpk GPG=/usr/bin/gpg \
    FINGER=/usr/bin/finger ABOOK=/usr/bin/abook \
    ADDR_EMAIL=/usr/bin/addr-email SH=/bin/sh \
    YPCAT=/usr/bin/ypcat MAWK=/usr/bin/awk \
    ./configure --prefix=%{_prefix} \
	--sysconfdir=%{_sysconfdir} \
	--mandir=%{_mandir} \
	--libdir=%{_libdir}/lbdb \
	--enable-lbdb-dotlock
make

%install
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}
BUILD_ROOT=${RPM_BUILD_ROOT} make \
	prefix=${RPM_BUILD_ROOT}%{_prefix} \
	sysconfdir=${RPM_BUILD_ROOT}%{_sysconfdir} \
	mandir=${RPM_BUILD_ROOT}%{_mandir} \
	libdir=${RPM_BUILD_ROOT}%{_libdir}/lbdb \
	install

%files
%defattr(-, root, root)
%doc README COPYING TODO
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/*
%{_libdir}/lbdb/*
%dir %{_libdir}/lbdb
%{_mandir}/man?/*

%changelog
* Thu Jan 29 2015 p.drouand@gmail.com
- Update to version 0.39
  * Use dh_autotools-dev (Closes: bdo#727289).
  * Update packaged autotools files.
  * Rebuild aclocal/autoconf.
  * Change debian/source-format to 3.0 (native).
  * Remove mutt-ja from Suggests, since this no longer exists.
  * Upgrade build depenency to debhelper (>= 9).
  * Change debian/compat to "9".
  * Complete rewrite of debian/rules.
  * Now uses hardening via debhelper.
  * Add $CPPFLAGS to $CFLAGS to really use hardening.
  * Upgrade to Standards-Version 3.9.5 (no changes).
  * m_vcf: Optimize missing names handling (Closes: bdo#624590).
  * Made debian/copyright machine readable.
  * m_abook: fix formatting (Closes: bdo#681526).
  * mutt-ldap-query: Add parameters for TLS and SASL_MECH (Closes: bdo#512074).
  * Mention user mutt-ldap-query configuration files in lbdbq(1) man page
    (Closes: bdo#534710).
  * Update ABQuery build mechanism
- Remove obsolete AUTHORS section
- Remove redundant %%clean section
- Do not package INSTALL file into doc directory
* Thu Aug  1 2013 lnussel@suse.de
- new version 0.38
  * m_evolution: Try to evaluate the location of
    evolution-addressbook-export at runtime, since it is no longer
    available in /usr/bin since evolution 2.30.1.2-3
    (Closes: #583851, #598380).
  * m_vcf: Apply patch by Jamey Sharp <jamey@minilop.net> to support VCF
    contacts without real name (Closes: #624590).
  * vcquery: Apply patch by martin f krafft <madduck@debian.org> to search
    in NICKNAME field, too. (Closes: #586300).
- remove lbdb-0.32-evolution.diff
* Tue Feb  8 2011 lnussel@suse.de
- Suggest perl(Net::LDAP) (bnc#669969)
* Wed May 19 2010 lnussel@suse.de
- new version 0.37
  * Fix bashisms in m_bbdb
  * Fix query shell functions to catch non-zero exit status in case they
    get invoked in set -e context.
  * m_evolution: support line breaks and long lines.
  * Fix documentation concerning the quotes on lbdbq call
- fix path to evolution-addressbook-export
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Oct  2 2008 lnussel@suse.de
- new version 0.36
  * Remove duplicate "See also: mutt" from lbdbq.man.
  * Update configure using autconf 2.61.
  * Apply charset conversation patch by Peter Colberg based on code by
    Tobias Schlemmer.
  * Remove duplicate declaration of $ignorant.
  * Handle mail addresses in mutt_ldap_query correct. Thanks to Colin
    Watson <cjwatson@debian.org> for providing a patch.
  * Mention ldapi URIs in mutt_ldap_query man page.
  * Protect "make distclean" by checking whether makefile exists.
  * Upgrade to Standards-Version 3.8.0:
  - Fix Homepage header in control file.
  * Add copyright holders to debian/copyright file.
  * Remove outdated override.Lintian.
* Fri Aug 10 2007 lnussel@suse.de
- new version 0.35.1
  * supports ldaps
* Wed May 16 2007 lnussel@suse.de
- new version 0.34
  * vcquery: avoid free() on unallocated memory if fullname is not set.
  * vcquery: Use value of concatenated N fields if FN field is missing.
- fix hostname lookup if multiple domains are listed in resolv.conf
* Mon Oct 16 2006 lnussel@suse.de
- new version 0.33
  * Add SORT_OUTPUT=reverse_comment to do reverse sort by the third column
    (most recent m_inmail timestamp at the top).
  * Comment out LDAP_NICKS in lbdb.rc because this should only be an
    example and if it is set there it overrides other LDAP settings
* Thu Aug 24 2006 lnussel@suse.de
- new version 0.32
- fix path to evolution-addressbook-export
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon May  9 2005 lnussel@suse.de
- update to version 0.30
* Fri Feb 27 2004 lnussel@suse.de
- run configure similar to the original debian package to reduce
  neededforbuild and to fix evolution addressbook query
- add gpg to default address query methods
* Thu Feb 26 2004 lnussel@suse.de
- update to version 0.29
* Sun Feb  8 2004 lnussel@suse.de
- update to version 0.28.2
- use %%optflags, fix aliasing problems
* Wed Feb 12 2003 lnussel@suse.de
- new version 0.26.2
  * new ldap option $ignorant
  * support for multiple abook address books
* Fri Aug 16 2002 ro@suse.de
- removed emtpy post/postun scripts (#17916)
* Thu Apr 25 2002 lnussel@suse.de
- new version 0.26
- now uses m_getent instead of m_passwd (lbdb.rc.dif)
- moved files from %%{_prefix}/lib to %%{_libdir}/lbdb
* Tue Jul 24 2001 lnussel@suse.de
- new version 0.25
* Tue Mar 20 2001 lnussel@suse.de
- new version 0.24
- added finger to neededforbuild
* Wed Feb  7 2001 lnussel@suse.de
- new version 0.23
- neededforbuild: ypbind -> yp-tools
* Thu Nov 30 2000 ro@suse.de
- neededforbuild: ypclient -> ypbind
* Thu Oct 12 2000 lnussel@suse.de
- new version 0.21.1
- cleaned up spec file
- changed Group to Applications/Mail
* Tue Aug 29 2000 lnussel@suse.de
- initial check in
